@@ -1,11 +1,17 @@
 mapDiversity <-
-function(data, resolution=1, plot=T, plot.with.grid=T, export=F, legend=T, filename="diversity_map") {
+function(data, resolution=1, plot=T, plot.with.grid=T, col=rev(terrain.colors(55)), alpha=0.8, export=F, legend=T, filename="diversity_map") {
   if (class(data) != "data.frame") {
     stop("data must be a data.frame")
   }
   if (ncol(data) != 3) {
     stop("data must have 3 columns, see help(\"mapDiversity\")")
   }
+  if (is.numeric(data[,2]) == F) {
+    stop("longitude must be numeric, see help(\"mapDiversity\")")
+  }
+  if (is.numeric(data[,3]) == F) {
+    stop("latitude must be numeric, see help(\"mapDiversity\")")
+  }
   wrld_simpl = NULL
   message("Assuming the columns are ordered as: species, longitude and latitude")
   data -> geo
@@ -13,7 +19,7 @@ function(data, resolution=1, plot=T, plot.with.grid=T, export=F, legend=T, filen
   coordinates(geo) = ~x+y
   r0 <- raster(resolution=resolution)
   r0[] <- NA
-  crop(r0, geo) -> r0
+  crop(r0,  extent(geo)++(resolution*2)) -> r0
   data.frame(spp=data[,1], cells=cellFromXY(r0, data[,2:3])) -> cells
   unique(cells) -> cells
   table(cells$cells) -> t.cells
@@ -30,7 +36,7 @@ function(data, resolution=1, plot=T, plot.with.grid=T, export=F, legend=T, filen
     data(wrld_simpl, envir = environment())
     plot(geo, col=NA)
     plot(wrld_simpl, add=T)
-    plot(r0, add=T, legend=legend)
+    plot(r0, add=T, legend=legend, col=col, alpha=alpha)
     if (plot.with.grid == T) {
       rasterToPolygons(r0) -> grid
       plot(grid, add=T, border="gray20", lwd=0.5)
